{
  config,
  pkgs,
  ...
}:

let
  domain = "headscale.vimium.net";
in
{
  environment.systemPackages = [ pkgs.headscale ];

  services.headscale = {
    enable = true;

    port = 8080;

    settings = {
      policy.path = null;
      ip_prefixes = [
        "100.64.0.0/10"
      ];
      server_url = "https://${domain}";
      derp = {
        auto_update_enable = false;
        update_frequency = "24h";
      };
      dns = {
        base_domain = "mesh.vimium.net";
        extra_records = [
          {
            name = "grafana.mesh.vimium.net";
            type = "A";
            value = "100.64.0.6";
          }
          {
            name = "home.mesh.vimium.net";
            type = "A";
            value = "100.64.0.7";
          }
        ];
        magic_dns = true;
        nameservers.global = [
          "9.9.9.9"
        ];
      };
      logtail.enabled = false;
    };
  };

  services.nginx.virtualHosts = {
    "${domain}" = {
      forceSSL = true;
      enableACME = true;
      locations."/" = {
        proxyPass = "http://localhost:${toString config.services.headscale.port}";
        proxyWebsockets = true;
      };
    };
  };
}
