{
  pkgs,
  config,
  lib,
  ...
}:

let
  inherit (lib)
    mkEnableOption
    mkIf
    ;
  cfg = config.modules.system.desktop.hyprland;
in
{
  options.modules.system.desktop.hyprland.enable = mkEnableOption "hyprland";

  config = mkIf cfg.enable {
    networking.networkmanager.enable = true;

    programs.hyprland = {
      enable = true;
      withUWSM = true;
    };

    nixpkgs.config.allowUnfree = true;

    stylix = {
      enable = true;
      autoEnable = false;
      image = config.lib.stylix.pixel "base00";
      polarity = "dark";

      # colors, dracula, eris, google-dark, framer, horizon-terminal-dark, humanoid-dark, isotope, onedark-dark, spacemacs, windows-nt
      base16Scheme = "${pkgs.base16-schemes}/share/themes/colors.yaml";

      cursor = {
        name = "macOS";
        package = pkgs.apple-cursor;
        size = 24;
      };

      fonts = {
        sansSerif = {
          name = "SF Pro Text";
          package = pkgs.sf-pro;
        };
        emoji = {
          name = "Apple Color Emoji";
          package = pkgs.apple-color-emoji;
        };
      };
    };
  };
}
